Тест задание для Франко.
Задача Pyhon - анализ успешности сотрудников. Автор проекта  Михаил Франко. Рабочая ОС-Linux Mint 19.1 Tessa. Основной скрипт пакета "worker.py" .
Пакет индексирован на PYPI как "workfrankomik".
Пакет установить: "pip install workfrankomik". 
Запускается из консоли командой "worker".
